@@ -29,17 +29,29 @@ void ListViewDelegate::setItemTextHighlightColor(const QColor& color)
     m_TextHighlightColor = color;
 }
 
+void ListViewDelegate::setItemTextDisabledColor(const QColor& color)
+{
+   m_TextDisabledColor = color;
+}
+
 QSize ListViewDelegate::sizeHint(const QStyleOptionViewItem & option , const QModelIndex & index) const
 {
     //handles size allocation of single item in the associated listview
     QIcon icon = qvariant_cast<QIcon>(index.data(iconRole));
     QSize iconsize = icon.actualSize(option.decorationSize);
     QFont font = QApplication::font();
-    if(m_HeaderFontPointSize!=-1)
-        font.setPointSize(m_HeaderFontPointSize);
+    if(index.data(headerItemSizeRole).isValid())
+    {
+        font.setPointSize(index.data(headerItemSizeRole).toInt());
+    }
+    else
+    {
+        if(m_HeaderFontPointSize!=-1)
+            font.setPointSize(m_HeaderFontPointSize);
+    }
     QFontMetrics fm(font);
 
-    return(QSize(iconsize.width(),iconsize.height()+fm.height() + 8));
+    return(QSize(iconsize.width(),iconsize.height()+fm.height() + 10));
 }
 
 void ListViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
@@ -50,14 +62,32 @@ void ListViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
 
     painter->save();
 
+    bool isHeaderItem = false;
+    QColor headerItemTextColor;
+
+
     QFont font = QApplication::font();
     QFont subFont = QApplication::font();
     font.setBold(true);
     subFont.setWeight(subFont.weight()-2);
-    if(m_HeaderFontPointSize!=-1)
-        font.setPointSize(m_HeaderFontPointSize);
-    if(m_SubHeaderFontPointSize!=-1)
-        subFont.setPointSize(m_SubHeaderFontPointSize);
+    if(index.data(headerItemRole).isValid())
+    {
+        isHeaderItem = index.data(headerItemRole).toBool();
+    }
+
+    if(isHeaderItem)
+    {
+        headerItemTextColor = qvariant_cast<QColor>(index.data(headerItemColorRole));
+        font.setPointSize(index.data(headerItemSizeRole).toInt());
+    }
+    else
+    {
+        if(m_HeaderFontPointSize!=-1)
+            font.setPointSize(m_HeaderFontPointSize);
+        if(m_SubHeaderFontPointSize!=-1)
+            subFont.setPointSize(m_SubHeaderFontPointSize);
+    }
+
 
     QFontMetrics fm(font);
     QFontMetrics fmSub(subFont);
@@ -94,24 +124,38 @@ void ListViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
         if(!(option.state & QStyle::State_Selected))
             painter->setPen(m_TextHighlightColor);
     }
+    else
+    {
+        if(isHeaderItem)
+        {
+            painter->setPen(headerItemTextColor); //set header item text color
+        }
+        else if(!(option.state & QStyle::State_Enabled))
+        { //draw item disabled in case not enabled
+            painter->setPen(m_TextDisabledColor);
+        }
+    }
 
     painter->setFont(font);
 
     painter->drawText(headerRect.left()-10,headerRect.top()+20,fm.elidedText(headerText,Qt::ElideRight,maxHeaderTextWidth));
 
-    int subTextRightJustifyLen = fmSub.width(subTextRightJustify); //get length of string in pixels
+    if(!isHeaderItem)
+    { //process for non-header item type only
+        int subTextRightJustifyLen = fmSub.width(subTextRightJustify); //get length of string in pixels
 
-    //calculate the max. allowed width of the left justified subheader text
-    int maxLeftJustifyTextWidth = subheaderRect.right()- subTextRightJustifyLen - (subheaderRect.left()+10);
-    if(maxLeftJustifyTextWidth>0)
-    {  //draw left justified part of subheader text
-        painter->setFont(subFont);
-        painter->drawText(subheaderRect.left()-10,subheaderRect.top()+17,fmSub.elidedText(subTextLeftJustify,Qt::ElideRight,maxLeftJustifyTextWidth));
+        //calculate the max. allowed width of the left justified subheader text
+        int maxLeftJustifyTextWidth = subheaderRect.right()- subTextRightJustifyLen - (subheaderRect.left()+10);
+        if(maxLeftJustifyTextWidth>0)
+        {  //draw left justified part of subheader text
+            painter->setFont(subFont);
+            painter->drawText(subheaderRect.left()-10,subheaderRect.top()+17,fmSub.elidedText(subTextLeftJustify,Qt::ElideRight,maxLeftJustifyTextWidth));
+        }
+
+        //draw right justified part of subheader text
+        painter->drawText(subheaderRect.right()-subTextRightJustifyLen,subheaderRect.top()+17,subTextRightJustify);
     }
 
-    //draw right justified part of subheader text
-    painter->drawText(subheaderRect.right()-subTextRightJustifyLen,subheaderRect.top()+17,subTextRightJustify);
-
     painter->restore();
  }
 
