@@ -3,14 +3,13 @@
 #include "QueueView.h"
 
 
-QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, QWidget* parent)
+QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, MCEWrapper *pMCEWrapper, QWidget* parent)
     : QMainWindow(parent)
 {
-    //construct the Queue View UI
+    //construct the QueueView UI
 
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow); //window is part of window stack
-   // setAttribute(Qt::WA_Maemo5AutoOrientation); //display auto-rotation
 #endif
 
     setWindowTitle(tr("Now Playing"));
@@ -22,6 +21,12 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, QWidget* pa
 
     m_playing = false; //set initial playback state
 
+    m_userInitiatedPause = false;
+
+    m_update = false;
+
+    m_lastTimeTrackActivated = QTime::currentTime(); //set to current time
+
     m_CallerID = QUEUEVIEW_ID;
 
     m_pOssoWrapper = pOsso; //set OssoWrapper instance pointer
@@ -30,6 +35,12 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, QWidget* pa
         connect(m_pOssoWrapper,SIGNAL(playbackStateChangeRequest(pb_state_e)),SLOT(OnPlaybackStateChangeRequest(pb_state_e)));
     }
 
+    m_pMCEWrapper = pMCEWrapper; //set MCE D-bus wrapper instance pointer
+    if(m_pMCEWrapper)
+    {
+       connect(m_pMCEWrapper,SIGNAL(onDisplayStateChange(bool)),SLOT(OnDisplayStateChanged(bool)));
+    }
+
     m_pCurrTrack = NULL;
     m_currQueuePos = 0;
     m_currShufflePos = 0;
@@ -79,7 +90,7 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, QWidget* pa
     connect(&m_PrevBtn,SIGNAL(clicked()),SLOT(OnPrevTrackBtn()));
     connect(&m_NextBtn,SIGNAL(clicked()),SLOT(OnNextTrackBtn()));
     connect(menuBar(),SIGNAL(triggered(QAction*)),SLOT(OnMenubarAction(QAction*)));
-    //connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
+    connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
 
     m_AlbumCover.setFixedSize(QUEUEVIEW_COVERART_WIDTH_LANDSCAPE,QUEUEVIEW_COVERART_HEIGHT_LANDSCAPE); //set fixed size of the album coverart
 
@@ -150,7 +161,7 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, QWidget* pa
     m_MainVertLayout.setLayout(m_pVertLayout);
 
     m_MainLayout.addWidget(&m_MainHorizLayout); //assign landscape mode grid layout
-    m_MainLayout.addWidget(&m_MainVertLayout); //add portrait mode layoyt
+    m_MainLayout.addWidget(&m_MainVertLayout); //add portrait mode layout
 
     setCentralWidget(&m_MainLayout);
 }
@@ -230,16 +241,15 @@ void QueueView::setListViewState()
 void QueueView::OnPlaybackStateChangeRequest(enum pb_state_e requestedState)
 {
    //request received via libplayback asking for a playback state change
-    if(requestedState==PB_STATE_STOP)
+    qDebug() << "Got here..";
+    if(((requestedState==PB_STATE_STOP)||(requestedState==PB_STATE_PLAY)) && !m_userInitiatedPause)
     { //request to move to stopped state, pause current playback
-        pauseResumePlayback(); //pause playback
-        m_playbackStateChangeReq = true; //indicate that playback state has been changed
-    }
-    else if(requestedState==PB_STATE_PLAY)
-    {
-        //request to resume playback
-        pauseResumePlayback(); //resume playback
-        m_playbackStateChangeReq = true; //indicate that playback state has been changed
+        qDebug() << "Request to pause / resume .. (state:" << requestedState << "), pause state: " << m_userInitiatedPause;
+        if(m_pCurrTrack)
+        {
+            pauseResumePlayback(); //pause playback
+            m_playbackStateChangeReq = true; //indicate that playback state has been changed
+        }
     }
 }
 
@@ -258,6 +268,9 @@ void QueueView::setQueueInitialState(QList<Spotify::Track*> queue, qint32 currQu
     m_currQueueBuffPos = currQueuePos; //initial buffering track pos
     m_shuffleStateChanged = false;
     m_currTrackScrobbled = false;
+    m_userInitiatedPause = false;
+
+    m_lastTimeTrackActivated.start();
 
     if(m_shuffle)
     { //shuffle mode active; shuffle the current play queue
@@ -318,16 +331,17 @@ void QueueView::clearViewSelection()
 
 void QueueView::OnPlayingState(bool state)
 {
-   if(state)
-   { //playing state
-      m_playing = true;
-      m_pSpectrum->Start();
-   }
-   else
-   { //paused state
-      m_playing = false;
-      m_pSpectrum->Stop();
-   }
+    if(state)
+    { //playing state
+        m_playing = true;
+        if(m_update)
+            m_pSpectrum->Start();
+    }
+    else
+    { //paused state
+        m_playing = false;
+        m_pSpectrum->Stop();
+    }
 }
 
 void QueueView::OnBufferNextTrack()
@@ -443,6 +457,8 @@ void QueueView::OnTrackActivated(QModelIndex index)
     //A track has been activated (e.g., selected) in the track list
     //Display artist and album cover pic (if available)
 
+    if(m_lastTimeTrackActivated.restart()>=400) //ignore successive (rapid) activations (within 400msecs since last activation)
+    {
         if(m_shuffleStateChanged)
             m_shuffleStateChanged=false;
 
@@ -468,6 +484,7 @@ void QueueView::OnTrackActivated(QModelIndex index)
             playTrack(m_pCurrTrack);
             emit playQueuePosUpdated(m_currQueuePos);
         }
+    }
 }
 
 void QueueView::playTrack(Spotify::Track* track)
@@ -486,6 +503,7 @@ void QueueView::playTrack(Spotify::Track* track)
     m_pSession->resetPlaybackMembers();
     loadTrackData(track);
     m_PauseResumeBtn.setChecked(true); //toggle playing state
+    m_userInitiatedPause = false;
     m_pProgressSlider->setPos1(0);
     m_pProgressSlider->setPos2(0);
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
@@ -518,16 +536,19 @@ void QueueView::OnTrackBufferedAmountUpdated(qint32 bufferedAmount)
     //Amount of buffered of the currently loaded / playing track has been updated
     int currPos;
 
-    if(m_currQueuePos != m_currQueueBuffPos)
+    if(m_update)
     {
-        currPos = m_currSliderWidth; //current track has been completely buffered
-    }
-    else
-    {
-        currPos = (bufferedAmount*m_currSliderWidth) / (m_currTrackDuration*1000); //current track has partly been buffered
-    }
+        if(m_currQueuePos != m_currQueueBuffPos)
+        {
+            currPos = m_currSliderWidth; //current track has been completely buffered
+        }
+        else
+        {
+            currPos = (bufferedAmount*m_currSliderWidth) / (m_currTrackDuration*1000); //current track has partly been buffered
+        }
 
-    m_pProgressSlider->setPos1(currPos); //set curr. slider position
+        m_pProgressSlider->setPos1(currPos); //set curr. slider position
+    }
 }
 
 void QueueView::OnPlaybackPositionUpdated(qint64 playbackPos)
@@ -536,35 +557,39 @@ void QueueView::OnPlaybackPositionUpdated(qint64 playbackPos)
 
     QString strCurrTrackProgressInfo, strCurrPlaybackPos, strCurrTrackDuration;
 
-    QTextStream outStream(&strCurrTrackProgressInfo);
+    if(m_update)
+    {
 
-    int seconds = ( playbackPos / 1000);
-    QTime currPlaybackPos = QTime( 0, 0, 0, 0 );
-    currPlaybackPos = currPlaybackPos.addSecs( seconds );
+        QTextStream outStream(&strCurrTrackProgressInfo);
 
-    if(!m_currTrackScrobbled && playbackPos>=240000)
-    {//scrobble track in case not already scrobbled (and track has played for at least 240 secs)
-       emit scrobbleTrack();
-       m_currTrackScrobbled = true;
+        int seconds = ( playbackPos / 1000);
+        QTime currPlaybackPos = QTime( 0, 0, 0, 0 );
+        currPlaybackPos = currPlaybackPos.addSecs( seconds );
+
+        if(!m_currTrackScrobbled && playbackPos>=240000)
+        {//scrobble track in case not already scrobbled (and track has played for at least 240 secs)
+           emit scrobbleTrack();
+           m_currTrackScrobbled = true;
+        }
+
+        if(m_pCurrTrack)
+        { //set track progress info in format current playback position / total track duration
+            if(currPlaybackPos.hour()>0)
+                strCurrPlaybackPos = currPlaybackPos.toString("h:mm:ss"); //position exceeds 60 mins
+            else
+                strCurrPlaybackPos = currPlaybackPos.toString("m:ss");
+            if(m_pCurrTrack->getDuration().hour()>0) //duration longer than 60 mins
+                strCurrTrackDuration = m_pCurrTrack->getDuration().toString("h:mm:ss");
+            else
+                strCurrTrackDuration = m_pCurrTrack->getDuration().toString("m:ss");
+            outStream << strCurrPlaybackPos << " / " << strCurrTrackDuration;
+            m_pProgressSlider->setText(strCurrTrackProgressInfo);
+        }
+
+        int currPos = (playbackPos*m_currSliderWidth) / (m_currTrackDuration*1000);
+
+        m_pProgressSlider->setPos2(currPos); //set curr. slider position
     }
-
-    if(m_pCurrTrack)
-    { //set track progress info in format current playback position / total track duration
-        if(currPlaybackPos.hour()>0)
-            strCurrPlaybackPos = currPlaybackPos.toString("h:mm:ss"); //position exceeds 60 mins
-        else
-            strCurrPlaybackPos = currPlaybackPos.toString("m:ss");
-        if(m_pCurrTrack->getDuration().hour()>0) //duration longer than 60 mins
-            strCurrTrackDuration = m_pCurrTrack->getDuration().toString("h:mm:ss");
-        else
-            strCurrTrackDuration = m_pCurrTrack->getDuration().toString("m:ss");
-        outStream << strCurrPlaybackPos << " / " << strCurrTrackDuration;
-        m_pProgressSlider->setText(strCurrTrackProgressInfo);
-    }
-
-    int currPos = (playbackPos*m_currSliderWidth) / (m_currTrackDuration*1000);
-
-    m_pProgressSlider->setPos2(currPos); //set curr. slider position
 }
 
 void QueueView::OnPauseResumeToggle()
@@ -576,7 +601,16 @@ void QueueView::OnPauseResumeToggle()
         if(m_playbackStateChangeReq)
         { //ask for state change
             m_playbackStateChangeReq = false;
-            m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_PLAY);
+            m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_PLAY); //notify via libplayback that we are entering playing state
+        }
+        if(!m_PauseResumeBtn.isChecked()) //entering paused state
+        {
+            qDebug() << "User paused playback..";
+            m_userInitiatedPause = true; //indicate that pausing of current track has been requested by user (used to ensure playback is not autoresumed by system upon notification from libplayback
+        }
+        else //entering playing state
+        {
+            m_userInitiatedPause = false;
         }
         m_pSession->pauseResumePlayback(); //pause / resume playback of current track
     }
@@ -586,7 +620,7 @@ void QueueView::pauseResumePlayback()
 {
     //request to pause / resume music playback (and set the UI to corresponding state)
 
-    m_pSession->pauseResumePlayback(); //pause playback
+    m_pSession->pauseResumePlayback(); //pause / resume playback
 
     if(m_playing)
     {
@@ -812,6 +846,8 @@ void QueueView::OnShuffleToggle()
     if(m_currQueuePos!=m_currQueueBuffPos)
         m_shuffleStateChanged = true; //indicate that current shuffle state has changed (enabled / disabled)
 
+    QRect screenGeometry = QApplication::desktop()->screenGeometry(); // get current screen geometry
+
     if(m_shuffle)
     {
         m_shuffle = false;
@@ -821,7 +857,15 @@ void QueueView::OnShuffleToggle()
     {
         shuffleQueue(); //shuffle the current playqueue
         m_shuffle = true;
-        setWindowTitle(tr("Now Playing") + " - " + tr("Shuffle"));
+        if (screenGeometry.width() > screenGeometry.height())
+        {
+            //landscape mode
+            setWindowTitle(tr("Now Playing") + " - " + tr("Shuffle"));
+        }
+        else
+        { //portrait mode
+            setWindowTitle(tr("Shuffle"));
+        }
     }
 }
 
@@ -958,6 +1002,10 @@ void QueueView::OnOrientationChanged()
     if (screenGeometry.width() > screenGeometry.height())
     {
         //switch to landscape mode
+        if(m_shuffle)
+        {
+            setWindowTitle(tr("Now Playing") + " - " + tr("Shuffle"));
+        }
         m_pVertLayout->removeWidget(&m_AlbumCover);
         m_pVertLayout->removeWidget(m_pTrackInfoView);
         m_pPlayerControlsVert->removeWidget(&m_PrevBtn);
@@ -987,6 +1035,10 @@ void QueueView::OnOrientationChanged()
     else
     {
         //switch to portrait mode
+        if(m_shuffle)
+        {
+            setWindowTitle(tr("Shuffle"));
+        }
         m_pHorizGridLayout->removeWidget(&m_AlbumCover);
         m_pHorizGridLayout->removeWidget(m_pTrackInfoView);
         m_pPlayerControlsHoriz->removeWidget(&m_PrevBtn);
@@ -1011,4 +1063,28 @@ void QueueView::OnOrientationChanged()
         m_pProgressLayoutVert->addWidget(m_pProgressSlider,0,0,1,-1);
         m_MainLayout.setCurrentIndex(PORTRAIT_ORIENTATION); //activate portrait layout
     }
+
+    OnTrackBufferedAmountUpdated(m_pSession->getBufferingPos()); //force update of track buffering position
+    OnPlaybackPositionUpdated(m_pSession->getPlaybackPos()); //force update of playback position
+}
+
+void QueueView::OnDisplayStateChanged(bool state)
+{
+    //display state changed notification (true=ON, false=OFF)
+    if(state)
+    { //display on
+        m_update = true; //allow UI updates
+        if(m_pCurrTrack)
+        {
+            if(m_playing)
+                m_pSpectrum->Start();
+            OnTrackBufferedAmountUpdated(m_pSession->getBufferingPos()); //force update of track buffering position
+            OnPlaybackPositionUpdated(m_pSession->getPlaybackPos()); //force update of playback position
+        }
+    }
+    else
+    { //display off
+        m_update = false; //no UI updates
+        m_pSpectrum->Stop();
+    }
 }
