@@ -16,6 +16,8 @@ TrackView::TrackView(Spotify::Session* pSession, QWidget* parent) :
 
         m_CallerID = TRACKVIEW_ID;
 
+        m_lastTimeTrackActivated.start();
+
         //init the track listview instance
         m_pTrackListView = new CListView(this);
         m_pTrackListModel = new QStandardItemModel(this);
@@ -287,13 +289,14 @@ void TrackView::OnTrackActivated(QModelIndex trackIndex)
 
     Q_UNUSED(trackIndex)
 
-    m_pTrackListView->setEnabled(false); //disable table temporarily
-
-    setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
-    setPlayQueue();
-    setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
-
-    m_pTrackListView->setEnabled(true); //re-enable the list view
+    if(m_lastTimeTrackActivated.restart()>=700) //ignore successive (rapid) activations (within 700msecs since last activation)
+    {
+        m_pTrackListView->setEnabled(false); //disable table temporarily
+        setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+        setPlayQueue();
+        setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+        m_pTrackListView->setEnabled(true); //re-enable the list view
+    }
 }
 
 
