@@ -16,6 +16,7 @@ ArtistView::ArtistView(Spotify::Session* pSession, QWidget* pParent)
     //setup signal / slot connections
     connect(m_pSession,SIGNAL(artistCatalogueReady(Spotify::ArtistCatalogue*)),SLOT(OnArtistCatalogueReady(Spotify::ArtistCatalogue*)));
     connect(&m_BiographyBtn,SIGNAL(clicked()),SLOT(OnArtistBiographyBtn()));
+    connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
 
     m_pAlbumListView = new QListView(this);
     m_pAlbumListViewDelegate = new ListViewDelegate(this);
@@ -35,6 +36,7 @@ ArtistView::ArtistView(Spotify::Session* pSession, QWidget* pParent)
     captionFont.setFamily(QApplication::font().family());
     captionFont.setPointSize(19);
     m_ArtistCaption.setFont(captionFont);
+    m_ArtistCaption.setAlignment(Qt::AlignCenter);
     m_ArtistCaption.setWordWrap(true);
 
     m_ArtistPortrait.setFixedSize(ARTIST_PORTRAIT_WIDTH, ARTIST_PORTRAIT_HEIGHT);
@@ -49,7 +51,6 @@ ArtistView::ArtistView(Spotify::Session* pSession, QWidget* pParent)
     m_pGridLayout->addWidget(m_pAlbumListView,2,1,1,1);
 
     setLayout(m_pGridLayout);
-
 }
 
 ArtistView::~ArtistView()
@@ -85,6 +86,7 @@ void ArtistView::setArtist(Spotify::Artist* pArtist)
             QMaemo5InformationBox::information(this,tr("Loading ") + pArtist->getName());
             m_ArtistCaption.setText(pArtist->getName());
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true);
+            m_ArtistPortrait.setVisible(false);
         }
     }
 }
@@ -241,6 +243,54 @@ void ArtistView::OnArtistPortraitLoaded()
 { //Album portrait ready / loaded
 
     if(m_pPortraitContainer)
+    {
         m_ArtistPortrait.setPixmap(QPixmap::fromImage(m_pPortraitContainer->getImage()).scaled(ARTIST_PORTRAIT_WIDTH,ARTIST_PORTRAIT_HEIGHT));
+        if(m_pPortraitContainer->getImage().isNull())
+            m_ArtistPortrait.setVisible(false);
+        else
+            m_ArtistPortrait.setVisible(true);
 
+    }
+}
+
+void ArtistView::setBiographyDlgOrientation(Qt::WidgetAttribute orientation)
+{
+    //set display orientation for the biography dialog instance
+    m_BiographyDlg.setAttribute(orientation);
+}
+
+void ArtistView::OnOrientationChanged()
+{
+    //device orientation changed (e.g, screen rotate)
+    QRect screenGeometry = QApplication::desktop()->screenGeometry(); // get current screen geometry
+
+    m_pGridLayout->removeWidget(&m_ArtistPortrait);
+    m_pGridLayout->removeWidget(&m_ArtistCaption);
+    m_pGridLayout->removeWidget(&m_BiographyBtn);
+    m_pGridLayout->removeWidget(m_pAlbumListView);
+
+    if (screenGeometry.width() > screenGeometry.height())
+    {
+        //switch to landscape mode
+        m_pGridLayout->addWidget(&m_ArtistPortrait,0,0,3,1);
+        m_pGridLayout->addWidget(&m_ArtistCaption,0,1,1,1);
+        m_pGridLayout->addWidget(&m_BiographyBtn,1,1,1,1);
+        m_pGridLayout->addWidget(m_pAlbumListView,2,1,1,1);
+
+        setFixedSize(APP_WIDTH,APP_HEIGHT); //resize dialog to fixed size
+
+        m_BiographyDlg.setFixedSize(APP_WIDTH,APP_HEIGHT);
+    }
+    else
+    {
+        //switch to portrait mode
+        m_pGridLayout->addWidget(&m_ArtistPortrait,0,0,3,1,Qt::AlignCenter);
+        m_pGridLayout->addWidget(&m_ArtistCaption,3,0,1,1);
+        m_pGridLayout->addWidget(&m_BiographyBtn,4,0,1,1);
+        m_pGridLayout->addWidget(m_pAlbumListView,5,0,1,1);
+
+        setFixedSize(APP_HEIGHT,APP_WIDTH); //resize dialog to fixed size
+
+        m_BiographyDlg.setFixedSize(APP_HEIGHT,APP_WIDTH);
+    }
 }
