@@ -35,13 +35,12 @@
 #include "customlabel.h"
 #include "OssoWrapper.h"
 #include "lastfmscrobbler.h"
+#include "MCEWrapper.h"
 
 
 //defines
 
-#define APP_VERSION "0.2.1-1" //application version string
-
-#define PLAYLIST_LOADING_TIMEOUT  30 //timeout before giving up on waiting for playlists to load (in seconds)
+#define APP_VERSION "0.8.0-1" //application version string
 
 class MainWindow : public QMainWindow
 {
@@ -80,6 +79,8 @@ private:
 
     OssoWrapper* m_pOssoWrapper; //wrapper instance for libosso
 
+    MCEWrapper* m_pMCEWrapper; //wrapper instance for MCE D-bus interface
+
     LastFMScrobbler* m_pLastFMScrobbler; //Last.fm scrobbling instance
 
     QPushButton m_SearchBtn;
@@ -114,6 +115,8 @@ private:
 
     bool m_playing; //TRUE if in playing mode
 
+    bool m_update; //TRUE in case UI elements should be updated
+
     qint64 m_currPlaybackPos; //playback position for currently playing track
 
     QMessageBox m_AboutDlg; //App About dialog instance
@@ -128,6 +131,8 @@ private:
 
     void setupInitialState(); //set up the app initial state (audio etc.)
 
+    void setDisplayOrientation(qint32 orientation); //set the display orientation
+
 
 
 private slots:
@@ -154,6 +159,8 @@ private slots:
      void OnScrobblingStatus(bool status, const QString& error);
      void OnScrobbleUpdateNowPlaying(const QString& strTrackName, const QString& strArtistName, const QString& strAlbumName, const QString& strAlbumArtist); //update Last.fm now playing info
      void OnScrobbleTrack(); //scrobble current track to Last.fm (and send scrobbles in queue)
+     void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
+     void OnDisplayStateChanged(bool state); //display state changed notification (i.e., true=ON, false=OFF)
 
 signals:
 
