@@ -145,10 +145,8 @@ void Spotify::Session::setPreBufferingActive(bool active)
     if(m_pAudioThread)
     {
         m_pAudioThread->getMutex()->lock();
-        qDebug() << "Set pre-buffering state: " << active;
         m_preBufActive = active;
         m_pAudioThread->setPreBufActive(active);
-        //m_pAudioThread->setNextTrackStartPos(-1);
         m_pAudioThread->getMutex()->unlock();
     }
 }
@@ -163,11 +161,21 @@ void Spotify::Session::setPlaybackPos(qint64 pos)
     m_playbackPos = pos;
 }
 
-void Spotify::Session::setBufferingPos(qint64 pos)
+qint64 Spotify::Session::getPlaybackPos()
+{
+    return m_playbackPos;
+}
+
+void Spotify::Session::setBufferingPos(qint32 pos)
 {
     m_bufferedAmount = pos;
 }
 
+qint32 Spotify::Session::getBufferingPos()
+{
+    return m_bufferedAmount;
+}
+
 
 void Spotify::Session::setPlaying(bool playing)
 {
@@ -298,10 +306,8 @@ Spotify::Error Spotify::Session::play( Spotify::Track* track, bool preBuffer )
     m_playing = false;
     m_currentTrack = track;
     Spotify::Error error;
-    QMutex mutex;
-    QWaitCondition sleep;
 
-    sleep.wait(&mutex,1300);
+    //sleep.wait(&mutex,1300);
 	
     // Disregard tracks that are not available:
     if( !track->isAvailable() )
@@ -342,8 +348,6 @@ Spotify::Error Spotify::Session::play( Spotify::Track* track, bool preBuffer )
         }
     }
 
-    //sleep.wait(&mutex,300);
-
     // Play track:
     qDebug() << "+play";
     error = sp_session_player_play( m_session, true );
